@@ -39,7 +39,6 @@ test_that("badRelativePaths identifies bad paths correctly", {
 })
 
 test_that("The linter identifies invalid application structures", {
-  expect_error(lint("."))
   expect_error(lint("shiny-app-in-subdir"))
   lint("shiny-app-in-subdir/my-app")
 })
@@ -76,3 +75,10 @@ test_that("The linter accepts a plumber API", {
   result <- lint("test-plumber")
   expect_false(is.null(result$plumber.R))
 })
+
+test_that("The linter accepts a TensorFlow Saved Model", {
+  lint("tf-saved-model")
+  lint("tf-human-readable-saved-model")
+  lint("tf-saved-model-rootdir")
+  expect_true(TRUE) # didn't stop()
+})
